<?php
/*
 * Plugin Name: Fildisi Extension
 * Description: This plugin extends Visual Composer and adds custom post type capabilities.
 * Author: Euthemians Team
 * Author URI: https://euthemians.com
 * Version: 2.5.1
 * Text Domain: fildisi-extension
 */

if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! defined( 'FILDISI_EXT_VERSION' ) ) {
	define( 'FILDISI_EXT_VERSION', '2.5.1' );
}

if ( ! defined( 'FILDISI_EXT_PLUGIN_DIR_PATH' ) ) {
	define( 'FILDISI_EXT_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'FILDISI_EXT_PLUGIN_DIR_URL' ) ) {
	define( 'FILDISI_EXT_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );
}

if ( ! class_exists( 'Fildisi_Extension_Plugin' ) ) {

	class Fildisi_Extension_Plugin {

		/**
		 * @action plugins_loaded
		 * @return Fildisi_Extension_Plugin
		 * @static
		 */
		public static function init()
		{

			static $instance = false;

			if ( ! $instance ) {
				load_plugin_textdomain( 'fildisi-extension' , false , dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
				$instance = new Fildisi_Extension_Plugin;
			}
			return $instance;

		}

		/* Add Visual Composer Plugin*/
		private function __construct() {

			if ( is_user_logged_in() ) {
				add_action( 'admin_enqueue_scripts' , $this->marshal( 'fildisi_ext_vce_extension_add_scripts' ) );
			}
			add_action( 'wp_enqueue_scripts' , $this->marshal( 'fildisi_ext_vce_extension_add_front_end_scripts' ) );

			require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-ext-metaboxes.php';
			require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-ext-functions.php';
			require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-ext-add-param.php';
			require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-ext-shortcode-param.php';


			//Shortcodes
			if( function_exists( 'vc_lean_map' ) || function_exists( 'vc_map' ) ) {

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_title.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_empty_space.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_divider.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_button.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_quote.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_dropcap.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_slogan.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_callout.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_progress_bar.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_pricing_table.php';

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_message_box.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_icon.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_icon_box.php';

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_image_text.php';
				//require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_double_image_text.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_media_box.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_single_image.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_gallery.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_slider.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_video.php';

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_social.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_social_links.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_gmap.php';

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_team.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_blog.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_portfolio.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_blog_leader.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_testimonial.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_counter.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_pie_chart.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_typed_text.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_promo.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_flexible_carousel.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_countdown.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_modal.php';
				if ( class_exists( 'woocommerce' ) ) {
					require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_products.php';
				}
				if ( class_exists( 'Tribe__Events__Main' ) ) {
					require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_events.php';
				}
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_content_slider.php';
				//require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_portfolio_parallax.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_language_selector.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_instagram.php';

				if ( function_exists( 'fildisi_eutf_visibility' ) ) {
					$content_manager = fildisi_eutf_visibility( 'vc_content_manager_visibility' );
					if ( $content_manager ) {
						require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'fildisi-templates/fildisi-templates.php';
					}
				}

				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_gtracking.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_gmaps.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_gfonts.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_video_embeds.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_required.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_policy_page_link.php';
				require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'shortcodes/fildisi_privacy_preferences_link.php';

			}

		}

		public function Fildisi_Extension_Plugin() {
			$this->__construct();
		}

		public function fildisi_ext_vce_extension_add_scripts( $hook ) {
			wp_enqueue_style('fildisi-ext-vc-elements', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/fildisi-ext-vc-elements.css', array(), time(), 'all');
			wp_enqueue_style('fildisi-ext-vc-custom-fields', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/fildisi-ext-vc-custom-fields.css', array(), time(), 'all');
			wp_enqueue_style('fildisi-ext-vc-simple-line-icons', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/simple-line-icons.css', array(), '2.2.3', 'all');
			wp_enqueue_style('fildisi-ext-vc-elegant-line-icons', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/et-line-icons.css', array(), '1.0.0', 'all');
		}

		public function fildisi_ext_vce_extension_add_front_end_scripts() {
			wp_register_style( 'fildisi-ext-vc-simple-line-icons', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/simple-line-icons.css', array(), '2.2.3', 'all' );
			wp_register_style( 'fildisi-ext-vc-elegant-line-icons', FILDISI_EXT_PLUGIN_DIR_URL .'assets/css/et-line-icons.css', array(), '1.0.0', 'all' );
		}

		public function marshal( $method_name ) {
			return array( &$this , $method_name );
		}
	}

	/**
	 * Initialize the Visual Composer Extension Plugin
	 */
	add_action( 'init' , array( 'Fildisi_Extension_Plugin' , 'init' ), 12 );


	/**
	 * Initialize Custom Post Types
	 */
	function fildisi_ext_vce_rewrite_flush() {
		fildisi_ext_vce_register_custom_post_init();
		flush_rewrite_rules();
	}
	register_activation_hook( __FILE__, 'fildisi_ext_vce_rewrite_flush' );

	function fildisi_ext_vce_register_custom_post_init() {
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-portfolio-post-type.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-testimonial-post-type.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-area-item-post-type.php';
	}
	add_action( 'init', 'fildisi_ext_vce_register_custom_post_init', 9 );

	function fildisi_ext_vce_body_class( $classes ){
		$fildisi_ext_ver = 'eut-vce-ver-' . FILDISI_EXT_VERSION;
		return array_merge( $classes, array( $fildisi_ext_ver ) );
	}
	add_filter( 'body_class', 'fildisi_ext_vce_body_class' );

	require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/fildisi-ext-global-functions.php';

	/**
	 * Widgets
	 */
	function fildisi_ext_register_widgets() {
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-image-banner.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-contact-info.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-latest-comments.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-latest-portfolio.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-latest-posts.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-social.php';
		require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'widgets/eut-widget-sticky.php';
		register_widget( 'Fildisi_Ext_Widget_Image_Banner' );
		register_widget( 'Fildisi_Ext_Widget_Contact_Info' );
		register_widget( 'Fildisi_Ext_Widget_Latest_Comments' );
		register_widget( 'Fildisi_Ext_Widget_Latest_Portfolio' );
		register_widget( 'Fildisi_Ext_Widget_Latest_Posts' );
		register_widget( 'Fildisi_Ext_Widget_Social' );
		register_widget( 'Fildisi_Ext_Widget_Sticky' );

	}
	add_action( 'widgets_init', 'fildisi_ext_register_widgets' );
	

	/**
	 *Admin Menu
	 */
	require_once FILDISI_EXT_PLUGIN_DIR_PATH . 'includes/admin/fildisi-ext-admin-functions.php';	
}

//Omit closing PHP tag to avoid accidental whitespace output errors.